package services

import (
	"errors"
	"hongze/hongze_cygx/models"
	"hongze/hongze_cygx/utils"
	"time"
)

func SpecialTripPopupMsg(activityInfo *models.CygxActivitySpecialDetail, user *models.WxUserItem) (signupStatus int, popupMsg, popupMsg2 string, err error) {
	//SignupStatus  int    `description:"返回状态：1：成功 、2 ：人数已满 、3：调研次数已用完、 4：超时"`
	signupStatus = 1
	resultTime := utils.StrTimeToTime(activityInfo.ActivityTime) //时间字符串格式转时间格式
	if time.Now().After(resultTime.Add(-time.Minute * 60)) {
		signupStatus = 4
		popupMsg = "活动开始前1小时内无法报名，请联系对口销售处理"
		return
	}

	errMsg, _, e := GetTripRemainingtimesBycompany(user, activityInfo)
	if e != nil {
		err = errors.New("获取客户剩余报名次数失败 GetActivitySpecialUserType, Err: " + e.Error())
		return
	}
	if errMsg != "" {
		popupMsg = errMsg
		signupStatus = 3
		return
	}
	var condition string
	var pars []interface{}

	condition += ` AND activity_id =  ? `
	pars = append(pars, activityInfo.ActivityId)

	tripTota, e := models.GetActivitySpecialTripCountByActivityId(condition, pars)
	if e != nil {
		err = errors.New("GetCygxActivitySpecialDetailList, Err: " + e.Error())
		return
	}
	if activityInfo.LimitPeopleNum-tripTota < 1 {
		signupStatus = 2
		popupMsg = "此活动报名人数已满，请留意下期活动"
		return
	}
	//signupStatus = 4
	popupMsg = "感谢参与，本次报名会扣除一次贵司在弘则的调研点数。"
	popupMsg2 = "由于每场活动人数有限，如果不能参加请提前48小时取消，未及时取消导致影响其他客户报名将会维持扣点。"
	return
}

//获取用户剩余报名次数
func GetTripRemainingtimesBycompany(user *models.WxUserItem, activityInfo *models.CygxActivitySpecialDetail) (errMsg string, tripRemaining int, err error) {

	//获取 专项调研客户类型   //1、永续客户 //2、大套餐客户（4个行业全开通的正式客户） //3、分行业套餐客户（开通对应行业的正式客户） //4、仅开通专家套餐的正式客户 //5、开通对应行业套餐或专家套餐的试用客户;6、冻结客户；7、流失客户 8：行业升级套餐客户
	msgTemplate := "您的专项调研次数已用完，如仍想参加，请与您的对口销售商议"
	var tripTota int
	userType, _, e := GetActivitySpecialUserType(user.CompanyId)
	if e != nil {
		err = errors.New("获取客户身份信息失败 GetActivitySpecialUserType, Err: " + e.Error())
		return
	}
	if userType == 0 {
		errMsg = msgTemplate
		return
	} else if userType == 1 {
		tripRemaining = 999
		return
	} else if userType == 2 {
		var condition string
		var pars []interface{}

		condition += ` AND company_id = ? `
		pars = append(pars, user.CompanyId)

		condition += ` AND is_valid = 1 `

		tripTota, e = models.GetActivitySpecialTripCountByActivitySpecial(condition, pars)
		if e != nil {
			err = errors.New("GetActivitySpecialTripCountByActivitySpecial, Err: " + e.Error())
			return
		}
		if tripTota >= 12 {
			errMsg = msgTemplate
			return
		}
		tripRemaining = 12 - tripTota
	} else {
		var condition string
		var pars []interface{}

		condition += ` AND company_id = ? `
		pars = append(pars, user.CompanyId)

		condition += ` AND chart_permission_id = ? `
		pars = append(pars, activityInfo.ChartPermissionId)

		condition += ` AND is_valid = 1 `

		tripTota, e = models.GetActivitySpecialTripCountByActivitySpecial(condition, pars)
		if e != nil {
			err = errors.New("GetActivitySpecialTripCountByActivitySpecial, Err: " + e.Error())
			return
		}
		if tripTota >= 6 {
			errMsg = msgTemplate
			return
		}
		tripRemaining = 6 - tripTota
	}
	return
}
